Crate bevy_wasm_tasks
source ·Structs
- The context arguments which are available to main thread callbacks requested using
run_on_main_thread. - The context arguments which are available to background tasks spawned onto the
WASMTasksRuntime. - The Bevy
Pluginwhich sets up theWASMTasksRuntimeBevy resource and registers thetick_runtime_updateexclusive system. - The Bevy
Resourcewhich allows for spawning new background tasks.
Functions
- The Bevy exclusive system which executes the main thread callbacks that background tasks requested using
run_on_main_thread. You can control which [CoreStage] this system executes in by specifying a customtick_stagevalue.